class CompaniesController < ApplicationController
  load_and_authorize_resource
  before_action :set_company, only: [:show, :edit, :update, :destroy]

  # GET /companies/1
  # GET /companies/1.json
  def show
   @events = Event.all.where(company_id: current_user.company_id)
   @companyUsers = User.all_users(current_user.company_id, current_user.id)
 end

  # GET /companies/new
  def new
    @company = Company.new
    @address = Address.new
  end

  # GET /companies/1/edit
  def edit
    @company = Company.find(params[:id])
    @address = Address.find_by_id(@company.address_id)
  end

  # POST /companies
  # POST /companies.json
  def create

    @address = Address.new(address_params)
    @company = Company.new(company_params)

    respond_to do |format|
      if @address.save
        @company.address_id = @address.id
        if @company.save
          if current_user.update(profile: 3, company_id: @company.id)
            format.html { redirect_to @company, notice: 'Company was successfully created.' }
            format.json { render :show, status: :created, location: @company }
          else
            format.html { render :new }
            format.json { render json: current_user.errors, status: :unprocessable_entity }
          end  
        else
         format.html { render :new }
         format.json { render json: @company.errors, status: :unprocessable_entity }
       end
     else
      format.html { render :new }
      format.json { render json: @address.errors, status: :unprocessable_entity }
    end
  end
end

  # PATCH/PUT /companies/1
  # PATCH/PUT /companies/1.json
  def update

    respond_to do |format|
      if @company.update(company_params)
        if @company.address.update(address_params)
          format.html { redirect_to @company, notice: 'Company was successfully updated.' }
          format.json { render :show, status: :ok, location: @company }
        else
         format.html { render :edit }
         format.json { render json: @company.errors, status: :unprocessable_entity }
       end
     else
      format.html { render :edit }
      format.json { render json: @company.errors, status: :unprocessable_entity }
    end
  end
end

  # DELETE /companies/1
  # DELETE /companies/1.json
  def destroy
    User.where(company_id: @company.id).update_all(profile: 1)
    @company.destroy
    current_user.update(profile: 1)
    respond_to do |format|
      format.html { redirect_to root_path, notice: 'Company was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_company
      @company = Company.find(params[:id])
    end

    def set_address
      @address = Address.find(params[:id]) || Address.new
    end
    # Never trust parameters from the scary internet, only allow the white list through.
    def company_params
      params.require(:company).permit(:id, :name, :cnpj, :address_id, 
        address: [:street, :city, :zip, :state] )
    end

    def address_params
      params.require(:address).permit(:street, :city, :zip, :state)
    end
  end
